# Architecture Decision Records

The Caikit project has [common Architecture Decision Records that can be found here](https://github.com/caikit/community/blob/main/adrs/README.md).

**NOTE**: There are a collection of seed ADRs planned in [issue #13](https://github.com/caikit/caikit/issues/13#issuecomment-1513403971). As such, numbers `001` through `017` are reserved for those ADRs as they're written.